package com.ym.mec.web.controller;

import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.write.style.column.LongestMatchColumnWidthStyleStrategy;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.microsvc.toolkit.common.response.paging.PageInfo;
import com.microsvc.toolkit.common.response.paging.QueryInfo;
import com.microsvc.toolkit.common.response.template.R;
import com.microsvc.toolkit.common.tools.DownloadManager;
import com.microsvc.toolkit.middleware.oss.OssPluginContext;
import com.microsvc.toolkit.middleware.oss.impl.TencentOssPlugin;
import com.ym.mec.biz.dal.entity.TempDirectorTrainingCamp;
import com.ym.mec.biz.dal.wrapper.TempDirectorTrainingCampDetailWrapper;
import com.ym.mec.biz.service.TempDirectorTrainingCampDetailService;
import com.ym.mec.biz.service.TempDirectorTrainingCampService;
import com.ym.mec.common.controller.BaseController;
import com.ym.mec.common.entity.HttpResponseResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.joda.time.DateTime;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.File;
import java.text.MessageFormat;
import java.util.List;

@Api(tags = "乐队指导训练营活动")
@RestController
@Slf4j
@RequestMapping("${app-config.url.web:}/tempDirectorTrainingDetailCamp")
public class TempDirectorTrainingCampDetailController extends BaseController {
    /**
     * 服务对象
     */
    @Resource
    private TempDirectorTrainingCampDetailService tempDirectorTrainingCampDetailService;

    @Autowired
    private OssPluginContext ossPluginContext;


    @Autowired
    private TempDirectorTrainingCampService tempDirectorTrainingCampService;


    @ApiOperation(value = "分页获取")
    @PostMapping("/queryPage")
    public HttpResponseResult<PageInfo<TempDirectorTrainingCampDetailWrapper.TempDirectorTrainingCampDetail>> queryPage(@RequestBody TempDirectorTrainingCampDetailWrapper.TempDirectorTrainingCampDetailQuery queryInfo){
        if (queryInfo.getTempDirectorTrainingCampId()==null) {
            return failed("训练营编号不能为空");
        }
        IPage<TempDirectorTrainingCampDetailWrapper.TempDirectorTrainingCampDetail> tempDirectorTrainingCampIPage = tempDirectorTrainingCampDetailService.queryPage(QueryInfo.getPage(queryInfo), queryInfo);

        return succeed(QueryInfo.pageInfo(tempDirectorTrainingCampIPage));
    }



    @ApiOperation(value = "导出")
    @PostMapping("/export")
    public HttpResponseResult<TempDirectorTrainingCampDetailWrapper.DownloadInfo> export(@RequestBody TempDirectorTrainingCampDetailWrapper.TempDirectorTrainingCampDetailQuery queryInfo){
        if (queryInfo.getTempDirectorTrainingCampId()==null) {
            return failed("训练营编号不能为空");
        }


        IPage<TempDirectorTrainingCampDetailWrapper.TempDirectorTrainingCampDetail> tempDirectorTrainingCampIPage = tempDirectorTrainingCampDetailService.queryPage(new Page<>(1,-1), queryInfo);
        List<TempDirectorTrainingCampDetailWrapper.TempDirectorTrainingCampDetail> records = tempDirectorTrainingCampIPage.getRecords();
        if (records.size()==0) {
            return failed("没有可导出数据");
        }
        TempDirectorTrainingCamp trainingCamp = tempDirectorTrainingCampService.getById(queryInfo.getTempDirectorTrainingCampId());

        for (TempDirectorTrainingCampDetailWrapper.TempDirectorTrainingCampDetail record : records) {
            record.setCityInfo(record.getProvince()+record.getCity()+record.getRegion());
            if (StringUtils.isNotBlank(record.getPaymentStatus())) {
                if ("PAID".equals(record.getPaymentStatus())) {
                    record.setPaymentStatusName("已缴费");
                } else if ("NO".equals(record.getPaymentStatus())) {
                    record.setPaymentStatusName("未缴费");
                } else if ("REFUND".equals(record.getPaymentStatus())) {
                    record.setPaymentStatusName("已退费");
                }
            }
        }
        TempDirectorTrainingCampDetailWrapper.DownloadInfo downloadInfo = generateExportExcelFile(records, TempDirectorTrainingCampDetailWrapper.TempDirectorTrainingCampDetail.class, trainingCamp.getName()+"导出", trainingCamp.getName()+"导出");
        return succeed(downloadInfo);
    }

    @ApiOperation(value = "统计")
    @PostMapping("/queryPageStat")
    public HttpResponseResult<TempDirectorTrainingCampDetailWrapper.TempDirectorTrainingCampDetailStat> queryPageStat(@RequestBody TempDirectorTrainingCampDetailWrapper.TempDirectorTrainingCampDetailQuery queryInfo){
        if (queryInfo.getTempDirectorTrainingCampId()==null) {
            return failed("训练营编号不能为空");
        }
        return succeed(tempDirectorTrainingCampDetailService.queryPageStat(queryInfo));
    }


    private TempDirectorTrainingCampDetailWrapper.DownloadInfo generateExportExcelFile(List<?> orderExports, Class<?> clazz, String fileName, String sheetName) {

        // OSS上传文件目录
        String uploadOssPath = MessageFormat.format("excel-download/{0}", DateTime.now().toString("yyyy-MM"));

        // 文件上传下载地址
        String uploadPath = MessageFormat.format("{0}/{1}-{2}.xlsx", uploadOssPath, fileName, DateTime.now().toString("MMddHHmmss"));

        // 本地文件地址
        String localPath = DownloadManager.getInstance().path(uploadPath);
//        log.debug("pageExport localPath={}", localPath);

        // 模板文件保存在springboot项目的resources/static下
        // Resource resource = new ClassPathResource("static/预报名模板导出.xlsx");

        EasyExcel
            .write(localPath, clazz)
            .registerWriteHandler(new LongestMatchColumnWidthStyleStrategy())
            //.withTemplate(resource.getStream()) // 利用模板的输出流
            .sheet(0, sheetName)
            .doWrite(orderExports);

        // 上传本地文件到OSS服务器
        String downloadPath = ossPluginContext.getPluginService(TencentOssPlugin.PLUGIN_NAME)
            .uploadFile(uploadOssPath, new File(localPath));
        log.debug("pageExport downloadPath={}", downloadPath);

        // 删除本地缓存文件
        DownloadManager.getInstance().deleteOnExit(localPath);

        // 学生统计下载
        return TempDirectorTrainingCampDetailWrapper.DownloadInfo
            .builder()
            .fileName(MessageFormat.format("{0}.xlsx", fileName))
            .downloadPath(downloadPath)
            .build();
    }

}

